package javax.naming.spi;

import javax.naming.InvalidNameException;
import javax.naming.CompositeName;
import javax.naming.Name;
import java.io.Serializable;

public class ResolveResult implements Serializable
{
    protected Object resolvedObj;
    protected Name remainingName;
    private static final long serialVersionUID = -4552108072002407559L;
    
    protected ResolveResult() {
        this.resolvedObj = null;
        this.remainingName = null;
    }
    
    public ResolveResult(Object resolvedObj, String n) {
        this.resolvedObj = resolvedObj;
        try {
            this.remainingName = new CompositeName(n);
        }
        catch (InvalidNameException ex) {}
    }
    
    public ResolveResult(Object resolvedObj, Name remainingName) {
        this.resolvedObj = resolvedObj;
        this.setRemainingName(remainingName);
    }
    
    public Name getRemainingName() {
        return this.remainingName;
    }
    
    public Object getResolvedObj() {
        return this.resolvedObj;
    }
    
    public void setRemainingName(Name name) {
        if (name != null) {
            this.remainingName = (Name)(Name)name.clone();
        }
        else {
            this.remainingName = null;
        }
    }
    
    public void appendRemainingName(Name name) {
        if (name != null) {
            if (this.remainingName != null) {
                try {
                    this.remainingName.addAll(name);
                }
                catch (InvalidNameException ex) {}
            }
            else {
                this.remainingName = (Name)(Name)name.clone();
            }
        }
    }
    
    public void appendRemainingComponent(String comp) {
        if (comp != null) {
            CompositeName compositeName = new CompositeName();
            try {
                compositeName.add(comp);
            }
            catch (InvalidNameException ex) {}
            this.appendRemainingName(compositeName);
        }
    }
    
    public void setResolvedObj(Object resolvedObj) {
        this.resolvedObj = resolvedObj;
    }
}
